print.ExhaustiveSearch: Print ExhaustiveSearch
Description
Prints a compact summary of the results of an ExhaustiveSearch object.
Usage
# S3 method for ExhaustiveSearch
print(x, ...)
Value
No return value. The function is only called to print results to the
console.
Arguments
- x
Object of class 'ExhaustiveSearch'.
- ...
Further arguments passed to or from other methods.